==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescriptionMetadata } from "./WebValidationErrorsDescriptionMetadata";
import { WebGridValidationStateDescription } from "./WebGridValidationStateDescription";
/**
 * @hidden
 */
export let WebGridValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridValidationStateDescriptionMetadata.a == null) {
                WebGridValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridValidationStateDescriptionMetadata.c(WebGridValidationStateDescriptionMetadata.a);
            }
            if (a.j(WebGridValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridValidationStateDescriptionMetadata.a);
            WebValidationErrorsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Status", "ExportedType:string:ValidationStatus");
            a.item("Status@names", "VALID;INVALID");
            a.item("Errors", "ExportedType:WebValidationErrors");
        }
        static d(a) {
            WebGridValidationStateDescriptionMetadata.b(a);
            a.aa("WebGridValidationState", () => new WebGridValidationStateDescription());
            a.z("WebGridValidationState", WebGridValidationStateDescriptionMetadata.a);
        }
    }
    WebGridValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridValidationStateDescriptionMetadata, 'WebGridValidationStateDescriptionMetadata');
    WebGridValidationStateDescriptionMetadata.a = null;
    return WebGridValidationStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescriptionMetadata } from "./WebValidationErrorsDescriptionMetadata";
import { WebGridValidationStateDescription } from "./WebGridValidationStateDescription";
/**
 * @hidden
 */
export let WebGridValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridValidationStateDescriptionMetadata.a == null) {
                WebGridValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridValidationStateDescriptionMetadata.c(WebGridValidationStateDescriptionMetadata.a);
            }
            if (a.k(WebGridValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridValidationStateDescriptionMetadata.a);
            WebValidationErrorsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Status", "ExportedType:string:ValidationStatus");
            a.item("Status@stringUnion", "WebComponents;React");
            a.item("Status@names", "VALID;INVALID");
            a.item("Errors", "ExportedType:WebValidationErrors");
        }
        static d(a) {
            WebGridValidationStateDescriptionMetadata.b(a);
            a.ac("WebGridValidationState", () => new WebGridValidationStateDescription());
            a.ab("WebGridValidationState", WebGridValidationStateDescriptionMetadata.a);
        }
    }
    WebGridValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridValidationStateDescriptionMetadata, 'WebGridValidationStateDescriptionMetadata');
    WebGridValidationStateDescriptionMetadata.a = null;
    return WebGridValidationStateDescriptionMetadata;
})();
